@@ -190,6 +190,17 @@ base_openvpn_schema = {
                     "pattern": "^(\\S*)$",
                     "propertyOrder": 17,
                 },
+                "tls_auth": {
+                    "title": "TLS Auth",
+                    "description": (
+                        "Adds an additional layer of HMAC authentication on top of "
+                        "the TLS control channel to mitigate DoS attacks and "
+                        "attacks on the TLS stack"
+                    ),
+                    "type": "string",
+                    "format": "textarea",
+                    "propertyOrder": 18,
+                },
                 "ns_cert_type": {
                     "title": "NS cert type",
                     "type": "string",
@@ -404,6 +415,17 @@ base_openvpn_schema = {
                     "format": "checkbox",
                     "propertyOrder": 43,
                 },
+                "auth_nocache": {
+                    "title": "auth nocache",
+                    "description": (
+                        "Immediately forget username/password"
+                        "inputs after they are used"
+                    ),
+                    "type": "boolean",
+                    "default": False,
+                    "format": "checkbox",
+                    "propertyOrder": 49,
+                },
                 "fast_io": {
                     "title": "fast IO",
                     "description": "(Experimental) Optimize TUN/TAP/UDP I/O writes by avoiding a "
@@ -495,6 +517,32 @@ base_openvpn_schema = {
                                         "minimum": 1,
                                         "propertyOrder": 2,
                                     },
+                                    "proto": {
+                                        "title": "protocol",
+                                        "type": "string",
+                                        "default": "auto",
+                                        "enum": [
+                                            "auto",
+                                            "udp",
+                                            "udp4",
+                                            "udp6",
+                                            "tcp",
+                                            "tcp4",
+                                            "tcp6",
+                                        ],
+                                        "options": {
+                                            "enum_titles": [
+                                                "Default (automatically determined)",
+                                                "UDP",
+                                                "UDP IPv4",
+                                                "UDP IPv6",
+                                                "TCP",
+                                                "TCP IPv4",
+                                                "TCP IPv6",
+                                            ]
+                                        },
+                                        "propertyOrder": 3,
+                                    },
                                 },
                             },
                         },
