@@ -3,6 +3,7 @@ import re
 from jinja2 import Environment, PackageLoader
 
 from ..openwrt.openwrt import OpenWrt
+from .renderer import OpenWrtRenderer
 from .schema import schema
 
 
@@ -12,6 +13,12 @@ class OpenWisp(OpenWrt):
     """
 
     schema = schema
+    renderer = OpenWrtRenderer
+
+    def __init__(
+        self, config=None, native=None, templates=None, context=None, dsa=False
+    ):
+        super().__init__(config, native, templates, context, dsa)
 
     def validate(self):
         self._sanitize_radios()
